/*
 * Copyright (c) 2002-2015, Mairie de Paris
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice
 *     and the following disclaimer.
 *
 *  2. Redistributions in binary form must reproduce the above copyright notice
 *     and the following disclaimer in the documentation and/or other materials
 *     provided with the distribution.
 *
 *  3. Neither the name of 'Mairie de Paris' nor 'Lutece' nor the names of its
 *     contributors may be used to endorse or promote products derived from
 *     this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * License 1.0
 */
package fr.paris.lutece.plugins.gru.business.demandtype;

import fr.paris.lutece.portal.service.plugin.Plugin;
import fr.paris.lutece.util.ReferenceList;

import java.util.List;

/**
 * IDemandTypeActionDAO Interface
 */
public interface IDemandTypeActionDAO
{
    /**
     * Insert a new record in the table.
     * 
     * @param demandTypeAction
     *            instance of the DemandTypeAction object to insert
     * @param plugin
     *            the Plugin
     */
    void insert( DemandTypeAction demandTypeAction, Plugin plugin );

    /**
     * Update the record in the table
     * 
     * @param demandTypeAction
     *            the reference of the DemandTypeAction
     * @param plugin
     *            the Plugin
     */
    void store( DemandTypeAction demandTypeAction, Plugin plugin );

    /**
     * Delete a record from the table
     * 
     * @param nKey
     *            The identifier of the DemandTypeAction to delete
     * @param plugin
     *            the Plugin
     */
    void delete( int nKey, Plugin plugin );

    // /////////////////////////////////////////////////////////////////////////
    // Finders

    /**
     * Load the data from the table
     * 
     * @param nKey
     *            The identifier of the demandTypeAction
     * @param plugin
     *            the Plugin
     * @return The instance of the demandTypeAction
     */
    DemandTypeAction load( int nKey, Plugin plugin );

    /**
     * Load the data of all the demandTypeAction objects and returns them as a collection
     * 
     * @param plugin
     *            the Plugin
     * @return The collection which contains the data of all the demandTypeAction objects
     */
    List<DemandTypeAction> selectDemandTypeActionsList( Plugin plugin );

    /**
     * Load the id of all the demandTypeAction objects and returns them as a collection
     * 
     * @param plugin
     *            the Plugin
     * @return The collection which contains the id of all the demandTypeAction objects
     */
    List<Integer> selectIdDemandTypeActionsList( Plugin plugin );

    /**
     * Select all Actions for a given demand type
     * 
     * @param nDemandTypeId
     *            The DemandType ID
     * @param plugin
     *            The plugin
     * @return The list
     */
    List<DemandTypeAction> selectActionsByType( int nDemandTypeId, Plugin plugin );

    /**
     * Select all Actions as a Reference List
     * 
     * @param plugin
     *            The plugin
     * @return The list
     */
    ReferenceList selectActionsReferenceList( Plugin _plugin );
}
